@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware;
 use strict;
 use warnings;
 
-our $VERSION = '1.022';
+our $VERSION = '1.023';
 
 use parent qw(CPANPLUS::Dist::Base);
 
@@ -1004,7 +1004,7 @@ CPANPLUS::Dist::Slackware - Install Perl distributions on Slackware Linux
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware version 1.022.
+This document describes CPANPLUS::Dist::Slackware version 1.023.
 
 =head1 SYNOPSIS
 
@@ -1023,7 +1023,7 @@ format?
 
 This CPANPLUS plugin creates Slackware compatible packages from Perl
 distributions.  You can either install the created packages using the API
-provided by CPANPLUS or manually via C<installpkg>.
+provided by CPANPLUS or manually with C<installpkg>.
 
 =head2 Using CPANPLUS::Dist::Slackware
 
@@ -1041,8 +1041,8 @@ C<dist_type> key:
 
     CPAN Terminal> s conf dist_type CPANPLUS::Dist::Slackware
 
-CPANPLUS sometimes fails to show interactive prompts if the C<verbose> option
-is not set.  Thus you might want to enable verbose output:
+Some Perl distributions fail to show interactive prompts if the C<verbose>
+option is not set.  Thus you might want to enable verbose output:
 
     CPAN Terminal> s conf verbose 1
 
@@ -1055,7 +1055,7 @@ User settings are stored in F<$HOME/.cpanplus/lib/CPANPLUS/Config/User.pm>.
 Packages may also be created from the command-line.  Example:
 
     $ cpan2dist --format CPANPLUS::Dist::Slackware Smart::Comments
-    $ sudo /sbin/installpkg /tmp/perl-Smart-Comments-1.0.4-i486-1_CPANPLUS.tgz
+    $ sudo /sbin/installpkg /tmp/perl-Smart-Comments-1.06-x86_64-1_CPANPLUS.tgz
 
 =head2 Managing packages as a non-root user
 
@@ -1242,8 +1242,8 @@ An external command failed to execute.
 
 =item B<< No dir found to operate on! >>
 
-For some reason, the Perl distribution's archive has not been extracted by
-CPANPLUS.
+For some reason, CPANPLUS could not extract the Perl distribution's archive
+file.
 
 =item B<< Unknown type 'CPANPLUS::Dist::WHATEVER' >>
 
@@ -1311,8 +1311,9 @@ Params::Check.
 
 =head1 INCOMPATIBILITIES
 
-Packages created with CPANPLUS::Dist::Slackware may conflict with packages
-from L<http://slackbuilds.org/> and packages created with C<cpan2tgz>.
+Packages created with CPANPLUS::Dist::Slackware may provide the same files as
+packages built with scripts from L<http://slackbuilds.org/> and packages created
+with C<cpan2tgz>.
 
 =head1 SEE ALSO
 
@@ -1325,9 +1326,9 @@ Andreas Voegele E<lt>voegelas@cpan.orgE<gt>
 
 =head1 BUGS AND LIMITATIONS
 
-CPANPLUS sometimes fails to show interactive prompts if the C<verbose> option
-is not set.  This has been reported as bug #47818 and bug
-#72095 at L<http://rt.cpan.org/>.
+Some Perl distributions fail to show interactive prompts if the C<verbose> option
+is not set.  This problem has been reported as bug #47818 and bug #72095 at
+L<http://rt.cpan.org/>.
 
 Please report any bugs to C<bug-cpanplus-dist-slackware at rt.cpan.org>, or
 through the web interface at L<http://rt.cpan.org/>.
