@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay;
 use strict;
 use warnings;
 
-our $VERSION = '1.022';
+our $VERSION = '1.023';
 
 use File::Spec qw();
 
@@ -40,11 +40,11 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay - Patch Crypt::SSLeay if necessary
+CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay - Patch Makefile.PL
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay version 1.022.
+This document describes CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay version 1.023.
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ This document describes CPANPLUS::Dist::Slackware::Plugin::Crypt::SSLeay version
 
 CPANPLUS executes F<Makefile.PL> with C<do> but Crypt::SSLeay's F<Makefile.PL>
 exits without creating a F<Makefile> if the script is run in the context of
-another call.  Reported as bug #98108 at L<http://rt.cpan.org/>.
+C<do>.  Reported as bug #98108 at L<http://rt.cpan.org/>.
 
 =head1 SUBROUTINES/METHODS
 
