@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::Plugin::GD;
 use strict;
 use warnings;
 
-our $VERSION = '1.022';
+our $VERSION = '1.023';
 
 use File::Spec qw();
 
@@ -62,11 +62,11 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Slackware::Plugin::GD - Patch GD
+CPANPLUS::Dist::Slackware::Plugin::GD - Patch Build.PL and the tests
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::Plugin::GD version 1.022.
+This document describes CPANPLUS::Dist::Slackware::Plugin::GD version 1.023.
 
 =head1 SYNOPSIS
 
