@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::Plugin::Net::Pcap;
 use strict;
 use warnings;
 
-our $VERSION = '1.022';
+our $VERSION = '1.023';
 
 use File::Spec qw();
 
@@ -43,11 +43,11 @@ __END__
 
 =head1 NAME
 
-CPANPLUS::Dist::Slackware::Plugin::Net::Pcap - Patch Net::Pcap if necessary
+CPANPLUS::Dist::Slackware::Plugin::Net::Pcap - Patch Makefile.PL
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::Plugin::Net::Pcap version 1.022.
+This document describes CPANPLUS::Dist::Slackware::Plugin::Net::Pcap version 1.023.
 
 =head1 SYNOPSIS
 
